ErrorCode

Enum ErrorCode 

pub enum ErrorCode {
Show 40 variants SubnetOversubscribed = 101, MaxNumberOfCanistersReached = 102, CanisterOutputQueueFull = 201, IngressMessageTimeout = 202, CanisterQueueNotEmpty = 203, CanisterNotFound = 301, CanisterMethodNotFound = 302, CanisterAlreadyInstalled = 303, CanisterWasmModuleNotFound = 304, InsufficientMemoryAllocation = 402, InsufficientCyclesForCreateCanister = 403, SubnetNotFound = 404, CanisterNotHostedBySubnet = 405, CanisterOutOfCycles = 501, CanisterTrapped = 502, CanisterCalledTrap = 503, CanisterContractViolation = 504, CanisterInvalidWasm = 505, CanisterDidNotReply = 506, CanisterOutOfMemory = 507, CanisterStopped = 508, CanisterStopping = 509, CanisterNotStopped = 510, CanisterStoppingCancelled = 511, CanisterInvalidController = 512, CanisterFunctionNotFound = 513, CanisterNonEmpty = 514, CertifiedStateUnavailable = 515, CanisterRejectedMessage = 516, QueryCallGraphLoopDetected = 517, UnknownManagementMessage = 518, InvalidManagementPayload = 519, InsufficientCyclesInCall = 520, CanisterWasmEngineError = 521, CanisterInstructionLimitExceeded = 522, CanisterInstallCodeRateLimited = 523, CanisterMemoryAccessLimitExceeded = 524, QueryCallGraphTooDeep = 525, QueryCallGraphTotalInstructionLimitExceeded = 526, CompositeQueryCalledInReplicatedMode = 527,
}
User-facing error codes.

The error codes are currently assigned using an HTTP-like convention: the most significant digit is the corresponding reject code and the rest is just a sequentially assigned two-digit number.

Variants



SubnetOversubscribed = 101



MaxNumberOfCanistersReached = 102



CanisterOutputQueueFull = 201



IngressMessageTimeout = 202



CanisterQueueNotEmpty = 203



CanisterNotFound = 301



CanisterMethodNotFound = 302



CanisterAlreadyInstalled = 303



CanisterWasmModuleNotFound = 304



InsufficientMemoryAllocation = 402



InsufficientCyclesForCreateCanister = 403



SubnetNotFound = 404



CanisterNotHostedBySubnet = 405



CanisterOutOfCycles = 501



CanisterTrapped = 502



CanisterCalledTrap = 503



CanisterContractViolation = 504



CanisterInvalidWasm = 505



CanisterDidNotReply = 506



CanisterOutOfMemory = 507



CanisterStopped = 508



CanisterStopping = 509



CanisterNotStopped = 510



CanisterStoppingCancelled = 511



CanisterInvalidController = 512



CanisterFunctionNotFound = 513



CanisterNonEmpty = 514



CertifiedStateUnavailable = 515



CanisterRejectedMessage = 516



QueryCallGraphLoopDetected = 517



UnknownManagementMessage = 518



InvalidManagementPayload = 519



InsufficientCyclesInCall = 520



CanisterWasmEngineError = 521



CanisterInstructionLimitExceeded = 522



CanisterInstallCodeRateLimited = 523



CanisterMemoryAccessLimitExceeded = 524



QueryCallGraphTooDeep = 525



QueryCallGraphTotalInstructionLimitExceeded = 526



CompositeQueryCalledInReplicatedMode = 527